@@ -32,10 +32,10 @@ class bitfinex:
 
         self.times_dict = {'5m': 5, '15m': 15, '30m': 30, '1h': 60, '3h': 180, '6h': 360, '12h': 720}
 
-    def get(self, limit=None, timeframe='1h', start=None, end=None, sort=-1, date=True, numpy_array=False):
+    def get(self, limit=None, timeframe='1h', start=None, end=None, symbol='tBTCUSD', sort=-1, date=True, numpy_array=False):
         start, end = self.timestamp_mts(start), self.timestamp_mts(end)
         query = {'limit': limit, 'start': start, 'end': end, 'sort': sort}
-        symbol = 'tBTCUSD'
+        # symbol = 'tBTCUSD'
         # symbol = 'tETHUSD'
 
         r = requests.get(f'https://api-pub.bitfinex.com/v2/candles/trade:{timeframe}:{symbol}/hist', params=query)
@@ -56,7 +56,7 @@ class bitfinex:
             return df['close'].to_numpy()
         return df
     
-    def get_hist(self, timeframe, start=1364778000, end=int(time.time())):
+    def get_hist(self, timeframe, start=1364778000, end=int(time.time()), symbol='tBTCUSD'):
         if timeframe not in self.times_dict:
             raise Exception('enter a valid timeframe')
 
@@ -71,7 +71,7 @@ class bitfinex:
             start_batch = start + (interval*i*120)
             end_batch = start_batch + (interval*120)
             try:
-                df_temp = self.get(timeframe=timeframe, start=str(start_batch), end=str(end_batch), date=False)
+                df_temp = self.get(timeframe=timeframe, start=str(start_batch), end=str(end_batch), date=False, symbol=symbol)
             except:
                 print('hata!', start_batch, end_batch)
                 if steps <= 1: return None
@@ -88,7 +88,7 @@ class bitfinex:
         df['date'] = pd.to_datetime(df['timestamp'], unit='s', utc=True)
         return df
     
-    def update_csv(self, path, timeframes=['1h'], alternative_mode=False):
+    def update_csv(self, path, timeframes=['1h'], alternative_mode=False, symbol='tBTCUSD'):
         # TODO fix time_toget for update_csv as well
         for times in timeframes:
             if '/' not in path:
@@ -108,7 +108,7 @@ class bitfinex:
             current_time = int(time.time())
 
             if alternative_mode:
-                df = self.get(10000, timeframe=times)
+                df = self.get(10000, timeframe=times, symbol=symbol)
                 for i in range(len(df)):
                     if df['timestamp'][i] == last_time:
                         df = df[i+1:]                  
@@ -134,4 +134,4 @@ class bitfinex:
                 return int(time)*1000
             else:
                 assert len(str(time)) == 13, 'Please use a timestamp value with lenght 10!'
-                return int(time)
\ No newline at end of file
+                return int(time)
